@@ -17,7 +17,7 @@ class DropboxBlueprint(Blueprint):
     """
     Blueprint to support work with Dropbox API in Flask projects.
     """
-    def __init__(self, dropbox, **kwargs):
+    def __init__(self, **kwargs):
         """
         Initialize blueprint instance and add all necessary URL to it.
         """
@@ -30,11 +30,10 @@ class DropboxBlueprint(Blueprint):
         super(DropboxBlueprint, self).__init__(**defaults)
 
         # Add URLs to the blueprint
-        url_defaults = {'dropbox': dropbox}
         url_map = {'/callback': callback, '/logout': logout}
 
         for url, view_func in url_map.items():
-            self.add_url_rule(url, defaults=url_defaults, view_func=view_func)
+            self.add_url_rule(url, view_func=view_func)
 
         if not BABEL_SUPPORTED:
             @self.app_context_processor
